import unittest
import numpy as np
import navipy.maths.euler as euler
import navipy.maths.constants as constants


class TestEuler(unittest.TestCase):
    def test_from_matrix(self):
        condition = dict()
        for key, _ in constants._AXES2TUPLE.items():
            rotation_0 = euler.matrix(1, 2, 3, key)
            ai, aj, ak = euler.from_matrix(rotation_0, key)
            rotation_1 = euler.matrix(ai, aj, ak, key)
            condition[key] = np.allclose(rotation_0,
                                         rotation_1)
            if condition[key] is False:
                print('axes', key, 'failed')
        self.assertTrue(np.all(np.array(condition.values())))

    def test_betweenconvention(self):
        """
        Test orientation from one convention to another
        """
        condition = dict()
        refkey = 'rxyz'
        for key, _ in constants._AXES2TUPLE.items():
            rotation_0 = euler.matrix(1, 2, 3, refkey)
            ai, aj, ak = euler.from_matrix(rotation_0, key)
            rotation_1 = euler.matrix(ai, aj, ak, key)
            condition[key] = np.allclose(rotation_0,
                                         rotation_1)
            if condition[key] is False:
                print('axes', key, 'failed')
        self.assertTrue(np.all(np.array(condition.values())))

    def test_from_quaternion(self):
        angles = euler.from_quaternion([0.99810947, 0.06146124, 0, 0])
        self.assertTrue(np.allclose(angles, [0.123, 0, 0]))


if __name__ == '__main__':
    unittest.main()
